@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-import re, json, os, sys, argparse, subprocess, tempfile
+import re, json, sys, argparse, subprocess
 import shutil
 from pathlib import Path
 
@@ -109,16 +109,17 @@ def save_and_compile_tex(out_dir, filename, lines, logs=False):
             Path.mkdir(complete_logs_out_dir, parents=True)
         print(f"- saved source as {complete_source_out_dir / filename}.tex")
 
-    with tempfile.TemporaryDirectory() as temp_dir:
-        run_args = ['pdflatex', f"-output-directory={temp_dir}", "-jobname=file"]
-       
-        subprocess.run(
-            run_args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, timeout=15,
-            input=Path(f"{complete_source_out_dir / filename}.tex").read_bytes())
-       
-        shutil.move(Path(temp_dir) / "file.pdf", f"{complete_out_dir / filename}.pdf" )
-        if logs:
-            shutil.move(Path(temp_dir) / "file.log", f"{complete_logs_out_dir / filename}.log" )
+    temp_dir = complete_out_dir / "tmp"
+
+    run_args = ['pdflatex', f"-output-directory={temp_dir}", "-jobname=file"]
+    
+    subprocess.run(
+        run_args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, timeout=15,
+        input=Path(f"{complete_source_out_dir / filename}.tex").read_bytes())
+    
+    shutil.move(Path(temp_dir) / "file.pdf", f"{complete_out_dir / filename}.pdf" )
+    if logs:
+        shutil.move(Path(temp_dir) / "file.log", f"{complete_logs_out_dir / filename}.log" )
 
     if logs:
         print(f"- generated pdf as {complete_out_dir / filename}.pdf")
